Widgets - Trident Chemwidgets - Docs v0.1

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Widgets

This section contains detailed information about the API of each Widget provided by the library.

- Histogram
  - Interaction features
    - Selecting data
    - Displaying selected structures
    - Saving selected subset to `selection` property
  - Example
- InteractiveMolecule
  - Input data structure
  - Interaction features
    - Atom information
  - Example
- JSME
  - Input
  - Interaction features
    - Creating a list of SMILES strings
    - Retrieving the list of SMILES strings
    - Using a `base_smiles` to quickly generate derivatives
  - Example
- Scatter
  - Interaction features
    - Selecting data
    - Displaying selected structures
    - Saving selected subset to `selection` property
  - Example